Crate calceph_sys

Structs

calcephbin

Constants

CALCEPH_ASTEROID
CALCEPH_MAX_CONSTANTNAME
CALCEPH_MAX_CONSTANTVALUE
CALCEPH_OUTPUT_EULERANGLES
CALCEPH_OUTPUT_NUTATIONANGLES
CALCEPH_SEGTYPE_ORIG_0
CALCEPH_SEGTYPE_SPK_1
CALCEPH_SEGTYPE_SPK_2
CALCEPH_SEGTYPE_SPK_3
CALCEPH_SEGTYPE_SPK_5
CALCEPH_SEGTYPE_SPK_8
CALCEPH_SEGTYPE_SPK_9
CALCEPH_SEGTYPE_SPK_12
CALCEPH_SEGTYPE_SPK_13
CALCEPH_SEGTYPE_SPK_14
CALCEPH_SEGTYPE_SPK_17
CALCEPH_SEGTYPE_SPK_18
CALCEPH_SEGTYPE_SPK_19
CALCEPH_SEGTYPE_SPK_20
CALCEPH_SEGTYPE_SPK_21
CALCEPH_SEGTYPE_SPK_102
CALCEPH_SEGTYPE_SPK_103
CALCEPH_SEGTYPE_SPK_120
CALCEPH_UNIT_AU
CALCEPH_UNIT_DAY
CALCEPH_UNIT_KM
CALCEPH_UNIT_RAD
CALCEPH_UNIT_SEC
CALCEPH_USE_NAIFID
CALCEPH_VERSION_MAJOR
CALCEPH_VERSION_MINOR
CALCEPH_VERSION_PATCH
NAIFID_ADRASTEA
NAIFID_AEGAEON
NAIFID_AEGIR
NAIFID_AITNE
NAIFID_ALBIORIX
NAIFID_AMALTHEA
NAIFID_ANANKE
NAIFID_ANTHE
NAIFID_AOEDE
NAIFID_ARCHE
NAIFID_AREND
NAIFID_AREND_RIGAUX
NAIFID_ARIEL
NAIFID_ASHBROOK_JACKSON
NAIFID_ATLAS
NAIFID_AUTONOE
NAIFID_BEBHIONN
NAIFID_BELINDA
NAIFID_BERGELMIR
NAIFID_BESTLA
NAIFID_BIANCA
NAIFID_BOETHIN
NAIFID_BORRELLY
NAIFID_BOWELL_SKIFF
NAIFID_BRADFIELD
NAIFID_BROOKS_2
NAIFID_BRORSEN_METCALF
NAIFID_BUS
NAIFID_CALIBAN
NAIFID_CALLIRRHOE
NAIFID_CALLISTO
NAIFID_CALYPSO
NAIFID_CARME
NAIFID_CARPO
NAIFID_CHALDENE
NAIFID_CHARON
NAIFID_CHERNYKH
NAIFID_CHURYUMOV_GERASIMENKO
NAIFID_CIFFREO
NAIFID_CLARK
NAIFID_COMAS_SOLA
NAIFID_CORDELIA
NAIFID_CRESSIDA
NAIFID_CROMMELIN
NAIFID_CUPID
NAIFID_CYLLENE
NAIFID_DANIEL
NAIFID_DAPHNIS
NAIFID_DEIMOS
NAIFID_DENNING_FUJIKAWA
NAIFID_DESDEMONA
NAIFID_DESPINA
NAIFID_DE_VICO_SWIFT
NAIFID_DIA
NAIFID_DIONE
NAIFID_DUBIAGO
NAIFID_DUTOIT_NEUJMIN_DELPORTE
NAIFID_DU_TOIT_1
NAIFID_DU_TOIT_HARTLEY
NAIFID_D__ARREST
NAIFID_EARTH
NAIFID_EARTH_MOON_BARYCENTER
NAIFID_ELARA
NAIFID_ENCELADUS
NAIFID_ENCKE
NAIFID_EPIMETHEUS
NAIFID_ERINOME
NAIFID_ERRIAPUS
NAIFID_EUANTHE
NAIFID_EUKELADE
NAIFID_EUPORIE
NAIFID_EUROPA
NAIFID_EURYDOME
NAIFID_FARBAUTI
NAIFID_FAYE
NAIFID_FENRIR
NAIFID_FERDINAND
NAIFID_FINLAY
NAIFID_FORBES
NAIFID_FORNJOT
NAIFID_FRANCISCO
NAIFID_GALATEA
NAIFID_GANYMEDE
NAIFID_GEHRELS_1
NAIFID_GEHRELS_2
NAIFID_GEHRELS_3
NAIFID_GIACOBINI_ZINNER
NAIFID_GICLAS
NAIFID_GREIP
NAIFID_GRIGG_SKJELLERUP
NAIFID_GUNN
NAIFID_HALE_BOPP
NAIFID_HALIMEDE
NAIFID_HALLEY
NAIFID_HANEDA_CAMPOS
NAIFID_HARPALYKE
NAIFID_HARRINGTON
NAIFID_HARRINGTON_ABELL
NAIFID_HARTLEY_1
NAIFID_HARTLEY_2
NAIFID_HARTLEY_3
NAIFID_HARTLEY_IRAS
NAIFID_HATI
NAIFID_HEGEMONE
NAIFID_HELENE
NAIFID_HELIKE
NAIFID_HELIN
NAIFID_HELIN_ROMAN_ALU_1
NAIFID_HELIN_ROMAN_CROCKETT
NAIFID_HERMIPPE
NAIFID_HERSCHEL_RIGOLLET
NAIFID_HERSE
NAIFID_HIMALIA
NAIFID_HOLMES
NAIFID_HOLT_OLMSTEAD
NAIFID_HONDA_MRKOS_PAJDUSAKOVA
NAIFID_HOWELL
NAIFID_HYAKUTAKE
NAIFID_HYDRA
NAIFID_HYPERION
NAIFID_HYROKKIN
NAIFID_IAPETUS
NAIFID_IJIRAQ
NAIFID_IO
NAIFID_IOCASTE
NAIFID_IRAS
NAIFID_ISONOE
NAIFID_JACKSON_NEUJMIN
NAIFID_JANUS
NAIFID_JARNSAXA
NAIFID_JOHNSON
NAIFID_JULIET
NAIFID_JUPITER
NAIFID_JUPITER_BARYCENTER
NAIFID_KALE
NAIFID_KALLICHORE
NAIFID_KALYKE
NAIFID_KARI
NAIFID_KEARNS_KWEE
NAIFID_KERBEROS
NAIFID_KIVIUQ
NAIFID_KLEMOLA
NAIFID_KOHOUTEK
NAIFID_KOJIMA
NAIFID_KOPFF
NAIFID_KORE
NAIFID_KOWAL_1
NAIFID_KOWAL_2
NAIFID_KOWAL_MRKOS
NAIFID_KOWAL_VAVROVA
NAIFID_LAOMEDEIA
NAIFID_LARISSA
NAIFID_LEDA
NAIFID_LEVY
NAIFID_LOGE
NAIFID_LONGMORE
NAIFID_LOVAS_1
NAIFID_LOVAS_2
NAIFID_LYSITHEA
NAIFID_MAB
NAIFID_MACHHOLZ
NAIFID_MARGARET
NAIFID_MARS
NAIFID_MARS_BARYCENTER
NAIFID_MAURY
NAIFID_MEGACLITE
NAIFID_MERCURY
NAIFID_MERCURY_BARYCENTER
NAIFID_METCALF_BREWINGTON
NAIFID_METHONE
NAIFID_METIS
NAIFID_MIMAS
NAIFID_MIRANDA
NAIFID_MNEME
NAIFID_MOON
NAIFID_MUELLER
NAIFID_MUELLER_2
NAIFID_MUELLER_3
NAIFID_MUNDILFARI
NAIFID_NAIAD
NAIFID_NARVI
NAIFID_NEPTUNE
NAIFID_NEPTUNE_BARYCENTER
NAIFID_NEREID
NAIFID_NESO
NAIFID_NEUJMIN_1
NAIFID_NEUJMIN_2
NAIFID_NEUJMIN_3
NAIFID_NIX
NAIFID_OBERON
NAIFID_OLBERS
NAIFID_OPHELIA
NAIFID_ORTHOSIE
NAIFID_PAALIAQ
NAIFID_PALLENE
NAIFID_PAN
NAIFID_PANDORA
NAIFID_PARKER_HARTLEY
NAIFID_PASIPHAE
NAIFID_PASITHEE
NAIFID_PERDITA
NAIFID_PETERS_HARTLEY
NAIFID_PHOBOS
NAIFID_PHOEBE
NAIFID_PLUTO
NAIFID_PLUTO_BARYCENTER
NAIFID_POLYDEUCES
NAIFID_PONS_BROOKS
NAIFID_PONS_WINNECKE
NAIFID_PORTIA
NAIFID_PRAXIDIKE
NAIFID_PROMETHEUS
NAIFID_PROSPERO
NAIFID_PROTEUS
NAIFID_PSAMATHE
NAIFID_PUCK
NAIFID_REINMUTH_1
NAIFID_REINMUTH_2
NAIFID_RHEA
NAIFID_ROSALIND
NAIFID_RUSSELL_1
NAIFID_RUSSELL_2
NAIFID_RUSSELL_3
NAIFID_RUSSELL_4
NAIFID_SANGUIN
NAIFID_SAO
NAIFID_SATURN
NAIFID_SATURN_BARYCENTER
NAIFID_SCHAUMASSE
NAIFID_SCHUSTER
NAIFID_SCHWASSMANN_WACHMANN_1
NAIFID_SCHWASSMANN_WACHMANN_2
NAIFID_SCHWASSMANN_WACHMANN_3
NAIFID_SETEBOS
NAIFID_SHAJN_SCHALDACH
NAIFID_SHOEMAKER_1
NAIFID_SHOEMAKER_2
NAIFID_SHOEMAKER_3
NAIFID_SHOEMAKER_HOLT_1
NAIFID_SHOEMAKER_LEVY_1
NAIFID_SHOEMAKER_LEVY_2
NAIFID_SHOEMAKER_LEVY_9
NAIFID_SIARNAQ
NAIFID_SIDING_SPRING
NAIFID_SINGER_BREWSTER
NAIFID_SINOPE
NAIFID_SKATHI
NAIFID_SKOLL
NAIFID_SLAUGHTER_BURNHAM
NAIFID_SMIRNOVA_CHERNYKH
NAIFID_SOLAR_SYSTEM_BARYCENTER
NAIFID_SPONDE
NAIFID_STEPHANO
NAIFID_STEPHAN_OTERMA
NAIFID_STYX
NAIFID_SUN
NAIFID_SURTUR
NAIFID_SUTTUNGR
NAIFID_SWIFT_GEHRELS
NAIFID_SYCORAX
NAIFID_TAKAMIZAWA
NAIFID_TARQEQ
NAIFID_TARVOS
NAIFID_TAYGETE
NAIFID_TAYLOR
NAIFID_TELESTO
NAIFID_TEMPEL_1
NAIFID_TEMPEL_2
NAIFID_TEMPEL_TUTTLE
NAIFID_TETHYS
NAIFID_THALASSA
NAIFID_THEBE
NAIFID_THELXINOE
NAIFID_THEMISTO
NAIFID_THRYMR
NAIFID_THYONE
NAIFID_TIME_CENTER
NAIFID_TIME_TCGMTCB
NAIFID_TIME_TTMTDB
NAIFID_TITAN
NAIFID_TITANIA
NAIFID_TRINCULO
NAIFID_TRITON
NAIFID_TRITTON
NAIFID_TSUCHINSHAN_1
NAIFID_TSUCHINSHAN_2
NAIFID_TUTTLE
NAIFID_TUTTLE_GIACOBINI_KRESAK
NAIFID_UMBRIEL
NAIFID_URANUS
NAIFID_URANUS_BARYCENTER
NAIFID_URATA_NIIJIMA
NAIFID_VAISALA_1
NAIFID_VAN_BIESBROECK
NAIFID_VAN_HOUTEN
NAIFID_VENUS
NAIFID_VENUS_BARYCENTER
NAIFID_WEST_KOHOUTEK_IKEMURA
NAIFID_WHIPPLE
NAIFID_WILD_1
NAIFID_WILD_2
NAIFID_WILD_3
NAIFID_WILD_4
NAIFID_WIRTANEN
NAIFID_WISEMAN_SKIFF
NAIFID_WOLF
NAIFID_WOLF_HARRINGTON
NAIFID_YMIR

Functions

calceph_close
close an ephemeris data file and destroy the ephemeris descriptor
calceph_compute
compute the position <x,y,z> and velocity <xdot,ydot,zdot> for a given target and center at a single time. The output is in UA, UA/day, radians
calceph_compute_order
According to the value of order, compute the position <x,y,z> and their first, second and third derivatives (velocity, acceleration, jerk) for a given target and center at a single time. The output is expressed according to unit
calceph_compute_unit
compute the position <x,y,z> and velocity <xdot,ydot,zdot> for a given target and center at a single time. The output is expressed according to unit
calceph_getconstant
get the first value from the specified name constant in the ephemeris file
calceph_getconstantcount
return the number of constants available in the ephemeris file
calceph_getconstantindex
return the name and the associated first value of the constant available at some index in the ephemeris file
calceph_getconstantsd
get the first value from the specified name constant in the ephemeris file
calceph_getconstantss
get the first value from the specified name constant in the ephemeris file
calceph_getconstantvd
get the nvalue values from the specified name constant in the ephemeris file
calceph_getconstantvs
get the nvalue values from the specified name constant in the ephemeris file
calceph_getfileversion
return the version of the ephemeris data file as a null-terminated string
calceph_getidbyname
return the id of the body using the given name in the ephemeris file
calceph_getmaxsupportedorder
return the maximal order of the derivatives for a segment type
calceph_getnamebyidss
return the first name of the body using its id in the ephemeris file
calceph_getorientrecordcount
return the number of orientation’s records available in the ephemeris file
calceph_getorientrecordindex
return the target body, the first and last time, and the reference frame available at the specified orientation’s records’ index of the ephemeris file
calceph_getorientrecordindex2
return the target body, the first and last time, the reference frame and the segment type available at the specified orientation’s records’ index of the ephemeris file
calceph_getpositionrecordcount
return the number of position’s records available in the ephemeris file
calceph_getpositionrecordindex
return the target and origin bodies, the first and last time, and the reference frame available at the specified position’s records’ index of the ephemeris file
calceph_getpositionrecordindex2
return the target and origin bodies, the first and last time, the reference frame and the segment type available at the specified position’s records’ index of the ephemeris file
calceph_gettimescale
return the time scale in the ephemeris file
calceph_gettimespan
return the first and last time available in the ephemeris file
calceph_getversion_str
return the version of the library as a null-terminated string
calceph_isthreadsafe
return non-zero value if eph could be accessed by multiple threads
calceph_open
open an ephemeris data file
calceph_open_array
open a list of ephemeris data file
calceph_orient_order
According to the value of order, compute the orientation and their first, second and third derivatives for a given target at a single time. The output is expressed according to unit
calceph_orient_unit
compute the orientation and their derivatives for a given target at a single time. The output is expressed according to unit
calceph_prefetch
prefetch all data to memory
calceph_rotangmom_order
compute the rotational angular momentum G/(mR^2) and their first, second and third derivatives for a given target at a single time. The output is expressed according to unit
calceph_rotangmom_unit
compute the rotational angular momentum G/(mR^2) and their derivatives for a given target at a single time. The output is expressed according to unit
calceph_sclose
close an ephemeris data file
calceph_scompute
compute the position <x,y,z> and velocity <xdot,ydot,zdot> for a given target and center
calceph_seterrorhandler
set the error handler
calceph_sgetconstant
get the first value from the specified name constant in the ephemeris file
calceph_sgetconstantcount
return the number of constants available in the ephemeris file
calceph_sgetconstantindex
return the name and the associated value of the constant available at some index in the ephemeris file
calceph_sgetfileversion
return the version of the ephemeris data file as a null-terminated string
calceph_sgettimescale
return the time scale in the ephemeris file
calceph_sgettimespan
return the first and last time available in the ephemeris file
calceph_sopen
open an ephemeris data file

Type Aliases

t_calcephbin
ephemeris descriptor
t_calcephcharvalue
fixed length string value of a constant