pub unsafe extern "C" fn calceph_close(eph: *mut t_calcephbin)Expand description
close an ephemeris data file and destroy the ephemeris descriptor
pub unsafe extern "C" fn calceph_close(eph: *mut t_calcephbin)close an ephemeris data file and destroy the ephemeris descriptor