pub unsafe extern "C" fn calceph_getconstantcount(
eph: *mut t_calcephbin,
) -> c_intExpand description
return the number of constants available in the ephemeris file
pub unsafe extern "C" fn calceph_getconstantcount(
eph: *mut t_calcephbin,
) -> c_intreturn the number of constants available in the ephemeris file