calceph_getpositionrecordindex2

Function calceph_getpositionrecordindex2 

pub unsafe extern "C" fn calceph_getpositionrecordindex2(
    eph: *mut t_calcephbin,
    index: c_int,
    target: *mut c_int,
    center: *mut c_int,
    firsttime: *mut f64,
    lasttime: *mut f64,
    frame: *mut c_int,
    segtype: *mut c_int,
) -> c_int
return the target and origin bodies, the first and last time, the reference frame and the segment type available at the specified position’s records’ index of the ephemeris file