calceph_orient_order

Function calceph_orient_order 

pub unsafe extern "C" fn calceph_orient_order(
    eph: *mut t_calcephbin,
    JD0: f64,
    time: f64,
    target: c_int,
    unit: c_int,
    order: c_int,
    PVAJ: *mut f64,
) -> c_int
According to the value of order, compute the orientation and their first, second and third derivatives for a given target at a single time. The output is expressed according to unit