calceph-sys 0.1.0

Rust FFI bindings to the calceph library for astronomical computations.
docs.rs failed to build calceph-sys-0.1.0
Please check the build logs for more information.
See Builds for ideas on how to fix a failed build, or Metadata for how to configure docs.rs builds.
If you believe this is docs.rs' fault, open an issue.
Visit the last successful build: calceph-sys-0.1.4

libcalceph-sys