pub unsafe extern "C" fn calceph_getpositionrecordindex(
eph: *mut t_calcephbin,
index: c_int,
target: *mut c_int,
center: *mut c_int,
firsttime: *mut f64,
lasttime: *mut f64,
frame: *mut c_int,
) -> c_intExpand description
return the target and origin bodies, the first and last time, and the reference frame available at the specified position’s records’ index of the ephemeris file